==> RcppParallel_4.3.8.tar.gz: RcppParallel/R/build.R <==


# Output the LD flags for building against TBB. These flags are propagated
# to sourceCpp via the inlineCxxPlugin (defined below) and to packages 
# via a line in Makevars.win like this:
#
#   PKG_LIBS += $(shell "${R_HOME}/bin${R_ARCH_BIN}/Rscript.exe" -e "RcppParallel::LdFlags()")
#
# Note that this is only required for Windows builds (on Linux and OS X no 
# explicit link to TBB is required).
RcppParallelLibs <- function() {
   cat(tbbLdFlags())
}


# Inline plugin used by sourceCpp to link to the TBB library
inlineCxxPlugin <- function() {
   list(
      env = list(
         PKG_CXXFLAGS = tbbCxxFlags(),
         PKG_LIBS = tbbLdFlags()
      ),
      includes = "#include <RcppParallel.h>",
      LinkingTo = "RcppParallel",
      body = function( x ) x,
      Depends = "RcppParallel"
   )
}

tbbCxxFlags <- function() {
   if (Sys.info()['sysname'] != "SunOS")
      flags <- "-Wno-long-long"
   else
      flags <- ""
   if (Sys.info()['sysname'] == "Windows")
      flags <- paste(flags, "-DRCPP_PARALLEL_USE_TBB=1")
   flags
}

# Return the linker flags requried for TBB on this platform
tbbLdFlags <- function() {
   # on Windows and Solaris we need to explicitly link against tbb.dll
   if (Sys.info()['sysname'] %in% c("Windows", "SunOS")) {
      tbb <- tbbLibPath()
      paste("-L", asBuildPath(dirname(tbb)), " -ltbb -ltbbmalloc", sep = "")
   } else {
      ""
   }
}

# Determine the platform-specific path to the TBB library
tbbLibPath <- function(suffix = "") {
   sysname <- Sys.info()['sysname']
   tbbSupported <- list(
      "Darwin" = paste("libtbb", suffix, ".dylib", sep = ""), 
      "Linux" = paste("libtbb", suffix, ".so.2", sep = ""), 
      "Windows" = paste("tbb", suffix, ".dll", sep = ""),
      "SunOS" = paste("libtbb", suffix, ".so", sep = "")
   )
   if (sysname %in% names(tbbSupported)) {
      libDir <- "lib/"
      if (sysname == "Windows")
         libDir <- paste(libDir, .Platform$r_arch, "/", sep="")
      system.file(paste(libDir, tbbSupported[[sysname]], sep = ""), 
                  package = "RcppParallel")
   } else {
      NULL
   }
}


# Helper function to ape the behavior of the R build system
# when providing paths to libraries
asBuildPath <- function(path) {
   if (.Platform$OS.type == "windows") {
      path <- normalizePath(path)
      if (grepl(' ', path, fixed=TRUE))
         path <- utils::shortPathName(path)
      path <- gsub("\\\\", "/", path)
   }
   return(path)
}

==> RcppParallel_4.3.14.tar.gz: RcppParallel/R/build.R <==


# Output the LD flags for building against TBB. These flags are propagated
# to sourceCpp via the inlineCxxPlugin (defined below) and to packages 
# via a line in Makevars.win like this:
#
#   PKG_LIBS += $(shell "${R_HOME}/bin${R_ARCH_BIN}/Rscript.exe" -e "RcppParallel::LdFlags()")
#
# Note that this is only required for Windows builds (on Linux and OS X no 
# explicit link to TBB is required).
RcppParallelLibs <- function() {
   cat(tbbLdFlags())
}


# Inline plugin used by sourceCpp to link to the TBB library
inlineCxxPlugin <- function() {
   list(
      env = list(
         PKG_CXXFLAGS = tbbCxxFlags(),
         PKG_LIBS = tbbLdFlags()
      ),
      includes = "#include <RcppParallel.h>",
      LinkingTo = "RcppParallel",
      body = function( x ) x,
      Depends = "RcppParallel"
   )
}

tbbCxxFlags <- function() {
   flags <- "$(CXX1XSTD)"
   if (Sys.info()['sysname'] == "Windows")
      flags <- paste(flags, "-DRCPP_PARALLEL_USE_TBB=1")
   flags
}

# Return the linker flags requried for TBB on this platform
tbbLdFlags <- function() {
   # on Windows and Solaris we need to explicitly link against tbb.dll
   if ((Sys.info()['sysname'] %in% c("Windows", "SunOS")) && !isSparc()) {
      tbb <- tbbLibPath()
      paste("-L", asBuildPath(dirname(tbb)), " -ltbb -ltbbmalloc", sep = "")
   } else {
      ""
   }
}

# Determine the platform-specific path to the TBB library
tbbLibPath <- function(suffix = "") {
   sysname <- Sys.info()['sysname']
   tbbSupported <- list(
      "Darwin" = paste("libtbb", suffix, ".dylib", sep = ""), 
      "Linux" = paste("libtbb", suffix, ".so.2", sep = ""), 
      "Windows" = paste("tbb", suffix, ".dll", sep = ""),
      "SunOS" = paste("libtbb", suffix, ".so", sep = "")
   )
   if ((sysname %in% names(tbbSupported)) && !isSparc()) {
      libDir <- "lib/"
      if (sysname == "Windows")
         libDir <- paste(libDir, .Platform$r_arch, "/", sep="")
      system.file(paste(libDir, tbbSupported[[sysname]], sep = ""), 
                  package = "RcppParallel")
   } else {
      NULL
   }
}

isSparc <- function() {
   Sys.info()['sysname'] == "SunOS" && Sys.info()[["machine"]] != "i86pc"
}

# Helper function to ape the behavior of the R build system
# when providing paths to libraries
asBuildPath <- function(path) {
   if (.Platform$OS.type == "windows") {
      path <- normalizePath(path)
      if (grepl(' ', path, fixed=TRUE))
         path <- utils::shortPathName(path)
      path <- gsub("\\\\", "/", path)
   }
   return(path)
}
